@@ -5,7 +5,7 @@
 $::PROTOCOL = '(?:s?https?|ftp)';
 $::RXURL    = '(?:s?https?|ftp)://[-\\w.!~*\'();/?:@&=+$,%#]+' ;
 $::charset  = 'EUC-JP';
-$::version  = '1.1.2_0 ($Date: 2006/07/29 12:00:56 $)';
+$::version  = '1.1.3_0 ($Date: 2006/08/12 05:28:04 $)';
 %::form     = ();
 $::me       = $::postme = $ENV{SCRIPT_NAME};
 $::print    = ' 'x 10000; $::print = '';
@@ -173,7 +173,8 @@ sub init_globals{
             { desc=>'forbid any one but administrator creating a new page.' ,
               name=>'lonely' , type=>'checkbox' },
             { desc=>'target value for external link.',name=>'target'},
-            { desc=>'pagename or url for CSS' , name=>'CSS' , size=>40 },
+            { desc=>'pagename(s) for CSS (1-line for 1-page)' ,
+              name=>'CSS' , type=>'textarea' , rows=>1 },
             { desc=>'pagename for FrontPage'  , name=>'FrontPage' , size=>40 },
         ],
         ' Section Marks' => [
@@ -446,19 +447,15 @@ sub print_header{
         <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
         <html lang="ja"><head>',$::charset);
     &puts( @::html_header );
-    &putenc('<title>%s</title>',$label);
-    my $cssn=$::config{CSS};
-    if( $cssn =~ /^http:/ || $cssn =~ /^\./ ){ ### URL for CSS
-        &putenc('<link rel="stylesheet" type="text/css" href="%s">',$cssn);
-    }else{ ### PAGE for CSS
-        my $css =&read_object($cssn);
-        if( $css ){
+    &putenc('<title>%s</title><style type="text/css"><!--',$label);
+    foreach my $p (split(/\s*\n\s*/,$::config{CSS})){
+        if( my $css =&read_object($p) ){
             $css =~ s/[<>&]//g;
             $css =~ s|/\*.*?\*/||gs;
-            &puts(qq(<style type="text/css"><!--\n${css}\n--></style>));
+            &puts( $css );
         }
     }
-    &puts('</head>');
+    &puts('--></style></head>');
     &puts( exists $::form{p} && &is_frozen($::form{p})
                 ? '<body class="frozen">' : '<body>' );
     &puts( @::body_header );
@@ -575,7 +572,7 @@ sub load_config{
 sub save_config{
     my @settings;
     while( my ($key,$val)=each %::config ){
-        push( @settings , "#$key\t$val" );
+        $val and push( @settings , '#'.$key."\t".&yen($val) );
     }
     &write_file( 'index.cgi' , join("\n", @settings) );
 }
@@ -671,6 +668,25 @@ sub action_tools{
                         (retype)<input type="password" name="%s_"><br>'
                     , $i->{desc} , $i->{name} , $i->{name}
                 );
+            }elsif( $i->{type} eq 'textarea' ){
+                &putenc(
+                    '%s<br><textarea name="%s" cols="%s" rows="%s">%s</textarea><br>'
+                    , $i->{desc} , $i->{name}
+                    , ($i->{cols} || 40 )
+                    , ($i->{rows} ||  4 )
+                    , exists $::config{$i->{name}} ? $::config{$i->{name}} : ''
+                );
+            }elsif( $i->{type} eq 'radio' ){
+                &putenc('%s<br>',$i->{desc});
+                foreach my $p (@{$i->{option}}){
+                    &putenc('<input type="radio" name="%s" value="%s"%s>%s<br>'
+                        , $i->{name}
+                        , $p->[0] 
+                        , ( defined($main::config{$i->{name}}) && 
+                            $main::config{$i->{name}} eq $p->[0]
+                          ? ' checked' : '' )
+                        , $p->[1] );
+                }
             }else{ # text
                 &putenc(
                     '%s <input type="text" name="%s" value="%s" size="%s"><br>'
@@ -682,8 +698,7 @@ sub action_tools{
         }
         &puts('</p></div></div>');
     }
-    &puts('Administrator\'s Sign:
-        <input type="password" name="password"
+    &puts('Sign: <input type="password" name="password"
         ><input type="hidden" name="a" value="preferences"
         ><input type="submit" value="Submit"></form></div></div>');
 
@@ -1000,11 +1015,11 @@ sub verbatim{
 }
 
 sub inner_link{
-    my $symbol = shift;
-    my $title  = &denc( shift );
+    my ($symbol,$title,$sharp) = ($_[0] , split(/(?=#[pf][0-9mt])/,$_[1]) );
+    $title = &denc($title);
 
     if( &object_exists($title) ){
-        &anchor( $symbol , { p=>$title } );
+        &anchor( $symbol , { p=>$title } , undef , $sharp);
     }else{
         qq(<blink>${symbol}?</blink>);
     }
